==> jei-1.19.4-fabric-13.1.0.8-sources.jar: mezz/jei/api/recipe/vanilla/IVanillaRecipeFactory.java <==
package mezz.jei.api.recipe.vanilla;

import mezz.jei.api.helpers.IJeiHelpers;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.registration.IRecipeRegistration;
import net.minecraft.class_1799;
import java.util.List;

/**
 * The {@link IVanillaRecipeFactory} allows creation of vanilla recipes.
 * Get the instance from {@link IJeiHelpers#getStackHelper()}.
 *
 * Use {@link IRecipeRegistration#addRecipes(RecipeType, List)} to add the recipe.
 */
public interface IVanillaRecipeFactory {
	/**
	 * Create an anvil recipe for the given inputs and output.
	 *
	 * @param leftInput   The itemStack placed on the left slot.
	 * @param rightInputs The itemStack(s) placed on the right slot.
	 * @param outputs     The resulting itemStack(s).
	 */
	IJeiAnvilRecipe createAnvilRecipe(class_1799 leftInput, List<class_1799> rightInputs, List<class_1799> outputs);

	/**
	 * Create an anvil recipe for the given inputs and output.
	 * The number of inputs in the left and right side must match.
	 *
	 * @param leftInputs  The itemStack(s) placed on the left slot.
	 * @param rightInputs The itemStack(s) placed on the right slot.
	 * @param outputs     The resulting itemStack(s).
	 */
	IJeiAnvilRecipe createAnvilRecipe(List<class_1799> leftInputs, List<class_1799> rightInputs, List<class_1799> outputs);

	/**
	 * Create a new brewing recipe.
	 * By default, all brewing recipes are already detected and added by JEI.
	 *
	 * @param ingredients  the ingredients added to a potion to create a new one.
	 *                     Normally one ingredient, but a list will display several in rotation.
	 * @param potionInput  the input potion for the brewing recipe.
	 * @param potionOutput the output potion for the brewing recipe.
	 */
	IJeiBrewingRecipe createBrewingRecipe(List<class_1799> ingredients, class_1799 potionInput, class_1799 potionOutput);

	/**
	 * Create a new brewing recipe.
	 * By default, all brewing recipes are already detected and added by JEI.
	 *
	 * @param ingredients  the ingredients added to a potion to create a new one.
	 *                     Normally one ingredient, but a list will display several in rotation.
	 * @param potionInputs the input potions for the brewing recipe.
	 * @param potionOutput the output potion for the brewing recipe.
	 */
	IJeiBrewingRecipe createBrewingRecipe(List<class_1799> ingredients, List<class_1799> potionInputs, class_1799 potionOutput);
}

==> jei-1.20.1-fabric-15.20.0.112-sources.jar: mezz/jei/api/recipe/vanilla/IVanillaRecipeFactory.java <==
package mezz.jei.api.recipe.vanilla;

import mezz.jei.api.helpers.IJeiHelpers;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.registration.IRecipeRegistration;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import java.util.List;

/**
 * The {@link IVanillaRecipeFactory} allows creation of vanilla recipes.
 * Get the instance from {@link IJeiHelpers#getStackHelper()}.
 *
 * Use {@link IRecipeRegistration#addRecipes(RecipeType, List)} to add the recipe.
 */
public interface IVanillaRecipeFactory {
	/**
	 * Create an anvil recipe for the given inputs and output.
	 *
	 * @param leftInput   The itemStack placed on the left slot.
	 * @param rightInputs The itemStack(s) placed on the right slot.
	 * @param outputs     The resulting itemStack(s).
	 * @param uid		  The unique ID for this recipe.
	 *
	 * @since 15.5.0
	 */
	IJeiAnvilRecipe createAnvilRecipe(class_1799 leftInput, List<class_1799> rightInputs, List<class_1799> outputs, class_2960 uid);

	/**
	 * Create an anvil recipe for the given inputs and output.
	 * The number of inputs in the left and right side must match.
	 *
	 * @param leftInputs  The itemStack(s) placed on the left slot.
	 * @param rightInputs The itemStack(s) placed on the right slot.
	 * @param outputs     The resulting itemStack(s).
	 * @param uid		  The unique ID for this recipe.
	 *
	 * @since 15.5.0
	 */
	IJeiAnvilRecipe createAnvilRecipe(List<class_1799> leftInputs, List<class_1799> rightInputs, List<class_1799> outputs, class_2960 uid);

	/**
	 * Create a new brewing recipe.
	 * By default, all brewing recipes are already detected and added by JEI.
	 *
	 * @param ingredients  the ingredients added to a potion to create a new one.
	 *                     Normally one ingredient, but a list will display several in rotation.
	 * @param potionInput  the input potion for the brewing recipe.
	 * @param potionOutput the output potion for the brewing recipe.
	 * @param uid		  The unique ID for this recipe.
	 *
	 * @since 15.5.0
	 */
	IJeiBrewingRecipe createBrewingRecipe(List<class_1799> ingredients, class_1799 potionInput, class_1799 potionOutput, class_2960 uid);

	/**
	 * Create a new brewing recipe.
	 * By default, all brewing recipes are already detected and added by JEI.
	 *
	 * @param ingredients  the ingredients added to a potion to create a new one.
	 *                     Normally one ingredient, but a list will display several in rotation.
	 * @param potionInputs the input potions for the brewing recipe.
	 * @param potionOutput the output potion for the brewing recipe.
	 * @param uid		  The unique ID for this recipe.
	 *
	 * @since 15.5.0
	 */
	IJeiBrewingRecipe createBrewingRecipe(List<class_1799> ingredients, List<class_1799> potionInputs, class_1799 potionOutput, class_2960 uid);

	/**
	 * Create an anvil recipe for the given inputs and output.
	 *
	 * @param leftInput   The itemStack placed on the left slot.
	 * @param rightInputs The itemStack(s) placed on the right slot.
	 * @param outputs     The resulting itemStack(s).
	 *
	 * @deprecated use {@link #createAnvilRecipe(class_1799, List, List, class_2960)}
	 */
	@Deprecated(since = "15.5.0")
	IJeiAnvilRecipe createAnvilRecipe(class_1799 leftInput, List<class_1799> rightInputs, List<class_1799> outputs);

	/**
	 * Create an anvil recipe for the given inputs and output.
	 * The number of inputs in the left and right side must match.
	 *
	 * @param leftInputs  The itemStack(s) placed on the left slot.
	 * @param rightInputs The itemStack(s) placed on the right slot.
	 * @param outputs     The resulting itemStack(s).
	 *
	 * @deprecated use {@link #createAnvilRecipe(List, List, List, class_2960)}
	 */
	@Deprecated(since = "15.5.0")
	IJeiAnvilRecipe createAnvilRecipe(List<class_1799> leftInputs, List<class_1799> rightInputs, List<class_1799> outputs);

	/**
	 * Create a new brewing recipe.
	 * By default, all brewing recipes are already detected and added by JEI.
	 *
	 * @param ingredients  the ingredients added to a potion to create a new one.
	 *                     Normally one ingredient, but a list will display several in rotation.
	 * @param potionInput  the input potion for the brewing recipe.
	 * @param potionOutput the output potion for the brewing recipe.
	 *
	 * @deprecated use {@link #createBrewingRecipe(List, class_1799, class_1799, class_2960)}
	 */
	@Deprecated(since = "15.5.0")
	IJeiBrewingRecipe createBrewingRecipe(List<class_1799> ingredients, class_1799 potionInput, class_1799 potionOutput);

	/**
	 * Create a new brewing recipe.
	 * By default, all brewing recipes are already detected and added by JEI.
	 *
	 * @param ingredients  the ingredients added to a potion to create a new one.
	 *                     Normally one ingredient, but a list will display several in rotation.
	 * @param potionInputs the input potions for the brewing recipe.
	 * @param potionOutput the output potion for the brewing recipe.
	 *
	 * @deprecated use {@link #createBrewingRecipe(List, List, class_1799, class_2960)}
	 */
	@Deprecated(since = "15.5.0")
	IJeiBrewingRecipe createBrewingRecipe(List<class_1799> ingredients, List<class_1799> potionInputs, class_1799 potionOutput);
}
